@@ -19,7 +19,7 @@ with 'Data::Object::Role::Stashable';
 
 use DBI;
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 # ATTRIBUTES
 
@@ -48,34 +48,54 @@ fun new_dsn($self) {
 
 has 'hostname' => (
   is => 'ro',
-  isa => 'Str',
-  def => $ENV{TESTDB_HOSTNAME},
+  isa => 'Maybe[Str]',
+  new => 1,
 );
 
+fun new_hostname($self) {
+  $ENV{TESTDB_HOSTNAME}
+}
+
 has 'hostport' => (
   is => 'ro',
-  isa => 'Str',
-  def => $ENV{TESTDB_HOSTPORT},
+  isa => 'Maybe[Str]',
+  new => 1,
 );
 
+fun new_hostport($self) {
+  $ENV{TESTDB_HOSTPORT}
+}
+
 has 'initial' => (
   is => 'ro',
   isa => 'Str',
-  def => $ENV{TESTDB_INITIAL} || 'mysql',
+  new => 1,
 );
 
+fun new_initial($self) {
+  $ENV{TESTDB_INITIAL} || 'mysql'
+}
+
 has 'username' => (
   is => 'ro',
   isa => 'Str',
-  def => $ENV{TESTDB_USERNAME} || 'root',
+  new => 1,
 );
 
+fun new_username($self) {
+  $ENV{TESTDB_USERNAME} || 'root'
+}
+
 has 'password' => (
   is => 'ro',
   isa => 'Str',
-  def => $ENV{TESTDB_PASSWORD} || '',
+  new => 1,
 );
 
+fun new_password($self) {
+  $ENV{TESTDB_PASSWORD} || ''
+}
+
 # METHODS
 
 method create() {
@@ -153,7 +173,7 @@ Temporary Mysql Database for Testing
 
   my $tdbo = Test::DB::Mysql->new;
 
-  # my $dbh = $tdbo->dbh;
+  # my $dbh = $tdbo->create->dbh;
 
 =cut
 
